pm4py.algo.transformation.log\_to\_features.variants package
============================================================

Submodules
----------

pm4py.algo.transformation.log\_to\_features.variants.event\_based module
------------------------------------------------------------------------

.. automodule:: pm4py.algo.transformation.log_to_features.variants.event_based
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.transformation.log\_to\_features.variants.trace\_based module
------------------------------------------------------------------------

.. automodule:: pm4py.algo.transformation.log_to_features.variants.trace_based
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.transformation.log_to_features.variants
   :members:
   :undoc-members:
   :show-inheritance:
